<?php
/**
 * $Id: modinfo.php,v 1.9 2005/04/13 06:18:31 tohokuaiki Exp $
 * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
 * Copyright (c) 2003 by Hiro SAKAI (http://wellwine.net/)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting
 * source code which is considered copyrighted (c) material of the
 * original comment or credit authors.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */








define('_MI_WEBLOG_NAME','weBLog');
define('_MI_WEBLOG_DESC','weBLogging/Journal system');
define('_MI_WEBLOG_SMNAME1','My weBLog');
define('_MI_WEBLOG_SMNAME2','Post');
define('_MI_WEBLOG_SMNAME3','Archives');

// submenu name
define('_MI_WEBLOG_DBMANAGER', 'Database');
define('_MI_WEBLOG_CATMANAGER', 'Categories');
define('_MI_WEBLOG_PRIVMANAGER', 'Privileges');
define('_MI_WEBLOG_MYBLOCKSADMIN', 'Blocks and Groups');

define('_MI_WEBLOG_NOTIFY','This weBLog');
define('_MI_WEBLOG_NOTIFYDSC','When something happens to this weBLog');
define('_MI_WEBLOG_ENTRY_NOTIFY','This weBLog entry');
define('_MI_WEBLOG_ENTRY_NOTIFYDSC','When something happens to this weBLog entry');

define('_MI_WEBLOG_ADD_NOTIFY','New Post');
define('_MI_WEBLOG_ADD_NOTIFYCAP','Notify me when a new post occurs');
define('_MI_WEBLOG_ADD_NOTIFYDSC','When a new post is made');
define('_MI_WEBLOG_ADD_NOTIFYSBJ','New weBLog Post');

define('_MI_WEBLOG_ENTRY_COMMENT','Comment Added');
define('_MI_WEBLOG_ENTRY_COMMENTDSC','Notify me when a new comment is posted for this item.');

define('_MI_WEBLOG_RECENT_BNAME1','Recent weBLogs');
define('_MI_WEBLOG_RECENT_BNAME1_DESC','Recent weBLog Entries');
define('_MI_WEBLOG_TOP_WEBLOGS','Top weBLogs');
define('_MI_WEBLOG_TOP_WEBLOGS_DESC','Top weBLogs');
define('_MI_WEBLOG_USERS_WEBLOGS','Users\' weBLogs');
define('_MI_WEBLOG_USERS_WEBLOGS_DESC','Recent weBLogs group by user');
define('_MI_WEBLOG_RECENT_TRACKBACKS','Recent Trackbacks');
define('_MI_WEBLOG_RECENT_TRACKBACKS_DESC','Recent Recieved Trackbacks ');
define('_MI_WEBLOG_RECENT_COMMENTS','Recent Comments');
define('_MI_WEBLOG_RECENT_COMMENTS_DESC','Recent Comments to weBLog entries');
define('_MI_WEBLOG_LINKS','weBLog owner\'s Links');
define('_MI_WEBLOG_LINKS_DESC','Links integrated with a links module');
define('_MI_WEBLOG_RECENT_IMAGES','Recent Images');
define('_MI_WEBLOG_RECENT_IMAGES_DESC','Recent Images used by weBLog');

// Config Settings
define('_MI_WEBLOG_NUMPERPAGE','Number of entries per page');
define('_MI_WEBLOG_NUMPERPAGEDSC','');
define('_MI_WEBLOG_DATEFORMAT','Date format');
define('_MI_WEBLOG_DATEFORMATDSC','');
define('_MI_WEBLOG_TIMEFORMAT','Time format');
define('_MI_WEBLOG_TIMEFORMATDSC','');
define('_MI_WEBLOG_RECENT_DATEFORMAT','Date format in Recent weBLog\'s');
define('_MI_WEBLOG_RECENT_DATEFORMATDSC','');
define('_MI_WEBLOG_SHOWAVATAR','Show users avatar on each entry');
define('_MI_WEBLOG_SHOWAVATARDSC','');
define('_MI_WEBLOG_ALIGNAVATAR','Align avatar');
define('_MI_WEBLOG_ALIGNAVATARDSC','');
define('_MI_WEBLOG_MINENTRYSIZE','Minimum size of entry (0=size checking disabled)');
define('_MI_WEBLOG_MINENTRYSIZEDSC','');
define('_MI_WEBLOG_IMGURL', 'Image URL');
define('_MI_WEBLOG_IMGURLDSC', 'URL of image that is shown or indicated in printer-friendly page and RSS');
define('_MI_WEBLOG_OPDOHTML', 'Option/Disable HTML') ;
define('_MI_WEBLOG_OPDOHTMLDSC', 'If you want to be checked disable HTML Option as default , set "Yes".') ;
define('_MI_WEBLOG_OPPRIVATE', 'Option/Private') ;
define('_MI_WEBLOG_OPPRIVATEDSC', 'If you want to be checked Private Option as default , set "Yes".') ;
define('_MI_WEBLOG_OPUPDATEPING', 'Option/Update ping') ;
define('_MI_WEBLOG_OPUPDATEPINGDSC', 'If you want to be checked Update ping Option as default , set "Yes".') ;

define('_MI_WEBLOG_UPDATE_READS_WHEN','Update read counter when');
define('_MI_WEBLOG_UPDATE_READS_WHENDSC','');
define('_MI_WEBLOG_UPDATE_READS_WHEN1','When viewing details');
define('_MI_WEBLOG_UPDATE_READS_WHEN2','When viewing users weBLog');
define('_MI_WEBLOG_UPDATE_READS_WHEN3','When viewing entry in any list');

define('_MI_WEBLOG_TEMPLATE_ENTRIESDSC','Display entries for the given weBLog');
define('_MI_WEBLOG_TEMPLATE_POSTDSC','Post a new weBLog entry');
define('_MI_WEBLOG_TEMPLATE_DETAILSDSC','Display details about a weBLog entry');
define('_MI_WEBLOG_TEMPLATE_RSSFEEDDSC','RSS feed of weBLog entries');
define('_MI_WEBLOG_TEMPLATE_PRINTDSC','Printer friendly page');
define('_MI_WEBLOG_TEMPLATE_ARCHIVEDSC','Monthly archives');
define('_MI_WEBLOG_TEMPLATE_IMAGEMANAGERDSC','weBLog Image Manager');

define('_MI_WEBLOG_EDITORHEIGHT','Height of editor box (lines)');
define('_MI_WEBLOG_EDITORHEIGHTDSC','');
define('_MI_WEBLOG_EDITORWIDTH','Width of editor box (characters)');
define('_MI_WEBLOG_EDITORWIDTHDSC','');
define('_MI_WEBLOG_ONLYADMIN',"Allow only module admin's to post?");
define('_MI_WEBLOG_ONLYADMINDSC','Setting to no will allow all registered users to post, while yes would mean only module administrators can post.');

// wellwine for read cookie
define('_MI_WEBLOG_EXPIRATION','Expiration of read count (second)');
define('_MI_WEBLOG_EXPIRATIONDSC','Define the time expiration of each blog read count. The count will be incremented if it has passed this period since last viewing.');
define('_MI_WEBLOG_RSSSHOW','Show an icon linked to RSS feed');
define('_MI_WEBLOG_RSSSHOWDSC','');
define('_MI_WEBLOG_RSSMAX','The number of entries to be fed in RSS');
define('_MI_WEBLOG_RSSMAXDSC','');

define('_MI_WEBLOG_USESEPARATOR','use entry division function');
define('_MI_WEBLOG_USESEPARATORDSC','inserting separator , you can divide entry as first half and latter half. First half is shown at index.php and Full entry is shown at details.php');
define('_MI_WEBLOG_USESMEMBERONLY','use menber only readable function');
define('_MI_WEBLOG_USESMEMBERONLYDSC','inserting separator , you can make part of entry which only registered member can read.');
define('_MI_WEBLOG_USEIMAGEMANAGER','use weBLog Image manager');
define('_MI_WEBLOG_USEIMAGEMANAGERDSC','You can use weBLog image manager different with XOOPS core image manager. It can deal thumbnail view.');


// myalbum-P imagemanager
// Config Items
define( "_MI_ALBM_CFG_PHOTOSPATH" , "Path to photos" ) ;
define( "_MI_ALBM_CFG_DESCPHOTOSPATH" , "Path from the directory installed XOOPS.<br />(The first character must be '/'. The last character should not be '/'.)<br />This directory's permission is 777 or 707 in unix." ) ;
define( "_MI_ALBM_CFG_THUMBSPATH" , "Path to thumbnails" ) ;
define( "_MI_ALBM_CFG_DESCTHUMBSPATH" , "Same as 'Path to photos'." ) ;
//define( "_MI_ALBM_CFG_THUMBWIDTH" , "Thumb Image Width" ) ;
//define( "_MI_ALBM_CFG_DESCTHUMBWIDTH" , "The height of thumbs will be decided from the width automatically." ) ;
define( "_MI_ALBM_CFG_THUMBSIZE" , "Size of thumbnails (pixel)" ) ;
define( "_MI_ALBM_CFG_THUMBRULE" , "Calc rule for building thumbnails" ) ;
define( "_MI_ALBM_CFG_WIDTH" , "Max photo width" ) ;
define( "_MI_ALBM_CFG_DESCWIDTH" , "This means the photo's width to be resized.<br />If you use GD without truecolor, this means the limitation of width." ) ;
define( "_MI_ALBM_CFG_HEIGHT" , "Max photo height" ) ;
define( "_MI_ALBM_CFG_DESCHEIGHT" , "Same as 'Max photo width'." ) ;
define( "_MI_ALBM_CFG_FSIZE" , "Max file size" ) ;
define( "_MI_ALBM_CFG_DESCFSIZE" , "The limitation of the size of uploading file.(byte)" ) ;
define( "_MI_ALBM_CFG_MIDDLEPIXEL" , "Max image size in single view" ) ;
define( "_MI_ALBM_CFG_DESCMIDDLEPIXEL" , "Specify (width)x(height)<br />eg) 480x480" ) ;

define( "_MI_ALBUM_OPT_CALCFROMWIDTH" , "width:specified  height:auto" ) ;
define( "_MI_ALBUM_OPT_CALCFROMHEIGHT" , "width:auto  width:specified" ) ;
define( "_MI_ALBUM_OPT_CALCWHINSIDEBOX" , "put in specified size squre" ) ;

?>